<?php

/**
 * black_bean_burrito_theme.php
 *    Name:   Black Bean Burrito
 * @author Ray Black
 *    Date:   August 15, 2000
 *
 * Copyright (c) 2000-2003 The SquirrelMail Project Team
 * Licensed under the GNU GPL. For full terms see the file COPYING.
 *
 * $Id: black_bean_burrito_theme.php,v 1.10 2003/10/28 20:58:29 tassium Exp $
 * @package squirrelmail
 * @subpackage themes
 */

global $color;
$color[0]   = '#595959'; // (mid-dark gray)     TitleBar
$color[1]   = '#F88888'; // (light red)         Quoted Replies in Emails
$color[2]   = '#ff7171'; // (pinkish)           Warning/Error Messages
$color[3]   = '#000000'; // (black)             Left Bar Background
$color[4]   = '#000000'; // (black)             Normal Background
$color[5]   = '#373700'; // (dark yellow-green) Table Headers
$color[6]   = '#D0D0D0'; // (off-white)         Text on left bar
$color[7]   = '#cfcfa0'; // (very dull yellow)  Links
$color[8]   = '#D0D0D0'; // (off-white)         Normal text
$color[9]   = '#414141'; // (dark gray)         Darker version of #0
$color[10]  = '#292929'; // (darker gray)       Darker version of #9
$color[11]  = '#AAAA44'; // (gold)		        Special Folders color
$color[12]  = '#202020'; // (dark gray)         Alternate color
$color[13]  = '#FF7733'; // (orange-ish)        Single-quoted text
$color[14]  = '#FF3377'; // (pink-ish)          2 or more quotes
$color[15]  = '#414141'; // (darker gray)       unselectable folders
?>
